summaryrefslogtreecommitdiff
path: root/decoders/z80
diff options
context:
space:
mode:
authorUwe Hermann <uwe@hermann-uwe.de>2014-04-13 19:57:43 +0200
committerUwe Hermann <uwe@hermann-uwe.de>2014-04-13 22:00:26 +0200
commit6a15597a7b3f901b566b7bfc8c484a14e0fb6a11 (patch)
treeee7241fa022b1b77f61affd373ff8baddb92d404 /decoders/z80
parent486858f7208207fb12a281640c5f6e9be4e4626f (diff)
downloadlibsigrokdecode-6a15597a7b3f901b566b7bfc8c484a14e0fb6a11.tar.gz
libsigrokdecode-6a15597a7b3f901b566b7bfc8c484a14e0fb6a11.zip
Rename 'probe' to 'channel' everywhere.
Variables of type 'struct srd_channel *' are consistently named 'pdch' to make them easily distinguishable from libsigrok's 'struct sr_channel *' variables that are consistently named 'ch'.
Diffstat (limited to 'decoders/z80')
-rw-r--r--decoders/z80/pd.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/decoders/z80/pd.py b/decoders/z80/pd.py
index f6bafb1..299a20e 100644
--- a/decoders/z80/pd.py
+++ b/decoders/z80/pd.py
@@ -56,7 +56,7 @@ ann_data_cycle_map = {
def reduce_bus(bus):
if 0xFF in bus:
- return None # unassigned bus probes
+ return None # unassigned bus channels
else:
return reduce(lambda a, b: (a << 1) | b, reversed(bus))
@@ -72,7 +72,7 @@ class Decoder(srd.Decoder):
license = 'gplv3+'
inputs = ['logic']
outputs = ['z80']
- probes = tuple({
+ channels = tuple({
'id': 'd%d' % i,
'name': 'D%d' % i,
'desc': 'Data bus line %d' % i
@@ -82,7 +82,7 @@ class Decoder(srd.Decoder):
{'id': 'rd', 'name': '/RD', 'desc': 'Memory or I/O read'},
{'id': 'wr', 'name': '/WR', 'desc': 'Memory or I/O write'},
)
- optional_probes = (
+ optional_channels = (
{'id': 'mreq', 'name': '/MREQ', 'desc': 'Memory request'},
{'id': 'iorq', 'name': '/IORQ', 'desc': 'I/O request'},
) + tuple({